==> mdm-rpc-0.0.30-sources.jar: com/chinayanghe/msp/mdm/rpc/eslog/CommonDataESVersionRpcService.java <==
package com.chinayanghe.msp.mdm.rpc.eslog;

import cn.com.bizunited.cp.common.pagination.Page;
import cn.com.bizunited.cp.common.pagination.Pageable;
import com.chinayanghe.msp.mdm.vo.eslog.BaseESVersionVo;

import java.util.List;

/**
 * 通用数据版本记录
 * @author bruce.qin
 * @usage
 * @reviewer
 * @since 2017/9/11
 */
public interface CommonDataESVersionRpcService {

    /**
     * 增加数据版本
     * @param versionVo
     */
    void addDataVersion(BaseESVersionVo versionVo);

    /**
     * 删除数据版本
     * @param className 类名称
     * @param id 数据id
     * @param versions 数据版本号（无指定删除所有）
     */
    void removeDataVersion(String className,String id,String... versions);

    /**
     * 删除所有数据版本
     * @param className 类名称
     * @param id 数据id
     */
    void removeAllDataVersion(String className,String id);


    /**
     * 查找数据版本（以版本号高到低排序）
     * @param className 类名称
     * @param id 数据id
     * @param versions 指定版本号
     * @return
     */
    List<BaseESVersionVo> findDataVersions(String className,String id,String... versions);

    /**
     * 查找所欲数据版本
     * @param className 类名称
     * @param id 数据id
     * @return
     */
    List<BaseESVersionVo> findDataAllVersions(String className,String id);

    /**
     * 查找最新一条版本
     * @param className 类名称
     * @param id 数据id
     * @return
     */
    BaseESVersionVo findLastVersionData(String className,String id);

    /**
     * 查找存在特殊字符串的版本信息
     * @param className 类名称
     * @param id 数据id
     * @param specialInfo 特殊信息
     * @return
     */
    List<BaseESVersionVo> findExistSpecialInfoDataVersion(String className,String id,String specialInfo );

    /**
     * 分页查询日志版本信息
     * @param className
     * @param id
     * @param pageable
     * @return
     */
    Page<BaseESVersionVo> findVersionDataPage(String className, String id, Pageable pageable);
}

==> mdm-rpc-0.1.100-sources.jar: com/chinayanghe/msp/mdm/rpc/eslog/CommonDataESVersionRpcService.java <==
package com.chinayanghe.msp.mdm.rpc.eslog;

import cn.com.bizunited.cp.common.pagination.Page;
import cn.com.bizunited.cp.common.pagination.Pageable;
import com.chinayanghe.msp.mdm.vo.eslog.BaseESVersionVo;

import java.util.List;

/**
 * 通用数据版本记录
 * @author bruce.qin
 * @usage
 * @reviewer
 * @since 2017/9/11
 */
public interface CommonDataESVersionRpcService {

    /**
     * 增加数据版本
     * @param versionVo
     */
    void addDataVersion(BaseESVersionVo versionVo);

    /**
     * 删除数据版本
     * @param className 类名称
     * @param id 数据id
     * @param versions 数据版本号（无指定删除所有）
     */
    void removeDataVersion(String className,String id,Long... versions);

    /**
     * 查找数据版本（以版本号高到低排序）
     * @param className 类名称
     * @param id 数据id
     * @param versions 指定版本号（无指定查询所有）
     * @return
     */
    List<BaseESVersionVo> findDataVersions(String className,String id,Long... versions);

    /**
     * 查找最新一条版本
     * @param className 类名称
     * @param id 数据id
     * @return
     */
    BaseESVersionVo findLastVersionData(String className,String id);

    /**
     * 查找存在特殊字符串的版本信息
     * @param className 类名称
     * @param id 数据id
     * @param specialInfo 特殊信息
     * @return
     */
    List<BaseESVersionVo> findExistSpecialInfoDataVersion(String className,String id,String specialInfo );

    /**
     * 分页查询日志版本信息
     * @param className
     * @param id
     * @param pageable
     * @return
     */
    Page<BaseESVersionVo> findVersionDataPage(String className, String id, Pageable pageable);
}
